#[non_exhaustive]pub enum HealthStatus {
Healthy,
Warning,
Critical,
Unknown,
}Expand description
Coarse health state derived from connection and error metrics.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Healthy
Connected with no significant recent failure rate.
Warning
Elevated failure rate or repeated failures.
Critical
High failure rate or sustained failures.
Unknown
Health cannot be established, commonly because there is no connection.